@@ -1,29 +1,31 @@
 # encoding: utf-8
-# pylint: disable=missing-docstring,no-self-use,too-few-public-methods,redefined-outer-name
+# pylint: disable=missing-docstring,no-self-use,redefined-outer-name
 
 from __future__ import unicode_literals
 
+import copy
 import io
 import os
 
 import pytest
 
-from dump2polarion.importer import do_import
-from dump2polarion.xunit_exporter import XunitExport
+from dump2polarion.exporters.xunit_exporter import XunitExport
+from dump2polarion.results.importer import import_results
 from tests import conf
 
 
 @pytest.fixture(scope="module")
 def records_names():
     input_file = os.path.join(conf.DATA_PATH, "ostriz.json")
-    return do_import(input_file)
+    return import_results(input_file)
 
 
 @pytest.fixture(scope="module")
 def config_cloudtp(config_prop):
-    config_prop["polarion-project-id"] = "CLOUDTP"
-    config_prop["cfme_parametrize"] = True
-    return config_prop
+    cloudtp = copy.deepcopy(config_prop)
+    cloudtp["polarion-project-id"] = "CLOUDTP"
+    cloudtp["cfme_parametrize"] = True
+    return cloudtp
 
 
 class TestParamE2E(object):
